#include "queueelement.h"

QueueElement::QueueElement (QString _url,QString _id, QString _info,int type) {
    this->id = _id;
    this->url = _url;
    this->info = _info;
    this->type = type;
}

QueueElement::QueueElement () {
    this->id = "";
    this->url = "";
    this->info = "";
}

QString QueueElement::getID() {
    return this->id;
}

QString QueueElement::getInfo() {
    return this->info;
}

QString QueueElement::getURL() {
    return this->url;
}

int QueueElement::getType() {
    return type;
}


void QueueElement::setID (QString i) {
    this->id = i;
}

void QueueElement::setInfo (QString i) {
    this->info = i;
}

void QueueElement::setURL (QString u) {
    this->url = u;
}

void QueueElement::setType(int t) {
   type = t;
}
